@@ -5,7 +5,7 @@ import mimetypes
 import os
 from typing import Optional, Union
 
-import gitlab
+from gitlab import exceptions, gitlab
 from requests import HTTPError, Session
 from requests.auth import AuthBase
 from urllib3 import Retry
@@ -13,6 +13,7 @@ from urllib3 import Retry
 from .errors import ImproperConfigurationError
 from .helpers import LoggedFunction, build_requests_session
 from .settings import config
+from .vcs_helpers import get_formatted_tag
 
 logger = logging.getLogger(__name__)
 
@@ -256,7 +257,7 @@ class Github(Base):
 
         :return: The status of the request
         """
-        tag = f"v{version}"
+        tag = get_formatted_tag(version)
         logger.debug(f"Attempting to create release for {tag}")
         success = Github.create_release(owner, repo, tag, changelog)
 
@@ -326,7 +327,7 @@ class Github(Base):
         """
 
         # Find the release corresponding to this version
-        release_id = Github.get_release(owner, repo, f"v{version}")
+        release_id = Github.get_release(owner, repo, get_formatted_tag(version))
         if not release_id:
             logger.debug("No release found to upload assets to")
             return False
@@ -410,17 +411,21 @@ class Gitlab(Base):
 
         :return: The status of the request
         """
-        ref = "v" + version
+        ref = get_formatted_tag(version)
         gl = gitlab.Gitlab(Gitlab.api_url(), private_token=Gitlab.token())
         gl.auth()
         try:
-            tag = gl.projects.get(owner + "/" + repo).tags.get(ref)
-            tag.set_release_description(changelog)
-        except gitlab.exceptions.GitlabGetError:
-            logger.debug(f"Tag {ref} was not found for project {owner}/{repo}")
-            return False
-        except gitlab.exceptions.GitlabUpdateError:
-            logger.debug(f"Failed to update tag {ref} for project {owner}/{repo}")
+            gl.projects.get(owner + "/" + repo).releases.create(
+                {
+                    "name": "Release " + version,
+                    "tag_name": ref,
+                    "description": changelog,
+                }
+            )
+        except exceptions.GitlabCreateError:
+            logger.debug(
+                f"Release {ref} could not be created for project {owner}/{repo}"
+            )
             return False
 
         return True
