@@ -46,6 +46,7 @@ def _config_from_ini(paths):
         "remove_dist",
         "upload_to_pypi",
         "upload_to_release",
+        "tag_commit",
     }
 
     # Iterate through the sections so that default values are applied
@@ -69,7 +70,7 @@ def _config_from_pyproject(path):
             if pyproject:
                 return pyproject.get("tool", {}).get("semantic_release", {})
         except TOMLKitError as e:
-            logger.debug(f"Could not decode pyproject.toml: {e}")
+            logger.warning(f"Could not decode pyproject.toml: {e}")
 
     return {}
 
